.. image:: https://github.com/snstac/pytak/blob/main/docs/atak_screenshot_with_pytak_logo-x25.jpg
   :alt: ATAK Screenshot with PyTAK Logo.
   :target: https://github.com/snstac/pytak/blob/main/docs/atak_screenshot_with_pytak_logo.jpg

Python Team Awareness Kit (PyTAK)
*********************************

PyTAK is a Python Module for creating TAK clients, servers & gateways and includes 
classes for handling Cursor on Target (CoT) & non-CoT data, as well as functions for 
serializing CoT data, and sending and receiving CoT data over a network.

Documentation
=============

See `PyTAK documentation <https://pytak.readthedocs.io/>`_.

TLS Support
===========

Moved: `PyTAK documentation <https://pytak.readthedocs.io/>`_.

License & Copyright
===================

Copyright 2023 Sensors & Signals LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

asyncio_dgram is Copyright (c) 2019 Justin Bronder and is licensed under the MIT 
License, see pytak/asyncio_dgram/LICENSE for details.
